@@ -71,8 +71,9 @@ gchar* current_rom_file = 0;
 gboolean current_rom_file_exists = FALSE;
 
 #if MAEMO_VERSION >= 5
+static GtkBox* buttons_hbox;
 static HildonButton* select_rom_btn;
-static HildonCheckButton* audio_check;
+static HildonCheckButton* sound_check;
 static HildonPickerButton* framerate_picker;
 static HildonCheckButton* display_fps_check;
 static HildonCheckButton* turbo_check;
@@ -80,7 +81,7 @@ static HildonCheckButton* turbo_check;
 #else
 static GtkButton* select_rom_btn;
 static GtkLabel* rom_label;
-static GtkCheckButton* audio_check;
+static GtkCheckButton* sound_check;
 static GtkCheckButton* turbo_check;
 static GtkComboBox* framerate_combo;
 static GtkCheckButton* accu_check;
@@ -165,6 +166,11 @@ static void controls_item_callback(GtkWidget * button, gpointer data)
 	controls_dialog(get_parent_window());
 }
 
+static void advanced_item_callback(GtkWidget * button, gpointer data)
+{
+	advanced_dialog(get_parent_window());
+}
+
 static void about_item_callback(GtkWidget * button, gpointer data)
 {
 	about_dialog(get_parent_window());
@@ -177,15 +183,31 @@ static GtkWidget * load_plugin(void)
 
 	GtkWidget* parent = gtk_vbox_new(FALSE, HILDON_MARGIN_DEFAULT);
 
-
 /* Select ROM button */
 #if MAEMO_VERSION >= 5
+// Very ugly hack ahead.
+{
+	buttons_hbox = GTK_BOX(gtk_hbox_new(FALSE, HILDON_MARGIN_DEFAULT));
+	// We can UNsafely assume gs.ui->play_button exists.
+
 	select_rom_btn = HILDON_BUTTON(hildon_button_new_with_text(
-		HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT,
-		HILDON_BUTTON_ARRANGEMENT_HORIZONTAL,
+		HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_THUMB_HEIGHT,
+		HILDON_BUTTON_ARRANGEMENT_VERTICAL,
 		"ROM",
 		NULL));
-	gtk_box_pack_start(GTK_BOX(parent), GTK_WIDGET(select_rom_btn), FALSE, FALSE, 0);
+	hildon_button_set_alignment(select_rom_btn, 0.0f, 0.5f, 0.9f, 0.2f);
+	gtk_box_pack_start_defaults(buttons_hbox, GTK_WIDGET(select_rom_btn));
+
+	gtk_widget_reparent(gs.ui->play_button, GTK_WIDGET(buttons_hbox));
+	hildon_gtk_widget_set_theme_size(gs.ui->play_button,
+		HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_THUMB_HEIGHT);
+	gtk_widget_set_size_request(gs.ui->play_button, 200, -1);
+	gtk_box_set_child_packing(buttons_hbox, gs.ui->play_button,
+		FALSE, FALSE, 0, GTK_PACK_START);
+
+	gtk_box_pack_start(GTK_BOX(parent), GTK_WIDGET(buttons_hbox), FALSE, FALSE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(parent), HILDON_MARGIN_HALF);
+}
 #else
 {
 	GtkWidget* rom_hbox = gtk_hbox_new(FALSE, HILDON_MARGIN_DEFAULT);
@@ -203,12 +225,14 @@ static GtkWidget * load_plugin(void)
 #if MAEMO_VERSION >= 5
 {
 	GtkBox* opt_hbox1 = GTK_BOX(gtk_hbox_new(FALSE, HILDON_MARGIN_DEFAULT));
-	audio_check =
-		HILDON_CHECK_BUTTON(hildon_check_button_new(HILDON_SIZE_AUTO));
-	gtk_button_set_label(GTK_BUTTON(audio_check), "Sound");
+	sound_check =
+		HILDON_CHECK_BUTTON(hildon_check_button_new(
+			HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT));
+	gtk_button_set_label(GTK_BUTTON(sound_check), "Sound");
 
 	framerate_picker = HILDON_PICKER_BUTTON(hildon_picker_button_new(
-		HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL));
+		HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT,
+		HILDON_BUTTON_ARRANGEMENT_HORIZONTAL));
 	hildon_button_set_title(HILDON_BUTTON(framerate_picker), "Target framerate");
 
 	HildonTouchSelector* framerate_sel =
@@ -237,15 +261,15 @@ static GtkWidget * load_plugin(void)
 	gtk_box_pack_start(GTK_BOX(framerate_sel), GTK_WIDGET(framerate_sel_box), FALSE, FALSE, 0);
 	gtk_widget_show_all(GTK_WIDGET(framerate_sel_box));
 
-	gtk_box_pack_start_defaults(opt_hbox1, GTK_WIDGET(audio_check));
+	gtk_box_pack_start_defaults(opt_hbox1, GTK_WIDGET(sound_check));
 	gtk_box_pack_start_defaults(opt_hbox1, GTK_WIDGET(framerate_picker));
 	gtk_box_pack_start(GTK_BOX(parent), GTK_WIDGET(opt_hbox1), FALSE, FALSE, 0);
 }
 #else
 {
 	GtkBox* opt_hbox1 = GTK_BOX(gtk_hbox_new(FALSE, HILDON_MARGIN_DEFAULT));
-	audio_check =
-		GTK_CHECK_BUTTON(gtk_check_button_new_with_label("Audio"));
+	sound_check =
+		GTK_CHECK_BUTTON(gtk_check_button_new_with_label("Enable sound"));
 
 	turbo_check =
 		GTK_CHECK_BUTTON(gtk_check_button_new_with_label("Turbo mode"));
@@ -254,7 +278,7 @@ static GtkWidget * load_plugin(void)
 	speedhacks_combo =
 		GTK_COMBO_BOX(gtk_combo_box_new_text());
 
-	gtk_box_pack_start(opt_hbox1, GTK_WIDGET(audio_check), FALSE, FALSE, 0);
+	gtk_box_pack_start(opt_hbox1, GTK_WIDGET(sound_check), FALSE, FALSE, 0);
 	gtk_box_pack_start(opt_hbox1, GTK_WIDGET(display_fps_check), TRUE, FALSE, 0);
 	gtk_box_pack_start(opt_hbox1, GTK_WIDGET(turbo_check), FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent), GTK_WIDGET(opt_hbox1), FALSE, FALSE, 0);
@@ -263,6 +287,7 @@ static GtkWidget * load_plugin(void)
 
 /* Second row of widgets */
 #if MAEMO_VERSION >= 5
+	// Empty
 #else
 {
 	GtkBox* opt_hbox2 = GTK_BOX(gtk_hbox_new(FALSE, HILDON_MARGIN_DEFAULT));
@@ -294,17 +319,17 @@ static GtkWidget * load_plugin(void)
 
 /* Load current configuration from GConf */
 #if MAEMO_VERSION >= 5
-	hildon_check_button_set_active(audio_check,
-		!gconf_client_get_bool(gcc, kGConfDisableAudio, NULL));
+	hildon_check_button_set_active(sound_check,
+		gconf_client_get_bool(gcc, kGConfSound, NULL));
 	hildon_picker_button_set_active(framerate_picker,
 		gconf_client_get_int(gcc, kGConfFrameskip, NULL));
 	hildon_check_button_set_active(turbo_check,
 		gconf_client_get_bool(gcc, kGConfTurboMode, NULL));
 	hildon_check_button_set_active(display_fps_check,
-		gconf_client_get_int(gcc, kGConfDisplayFramerate, NULL));
+		gconf_client_get_bool(gcc, kGConfDisplayFramerate, NULL));
 #else
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(audio_check),
-		!gconf_client_get_bool(gcc, kGConfDisableAudio, NULL));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sound_check),
+		gconf_client_get_bool(gcc, kGConfSound, NULL));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(turbo_check),
 		gconf_client_get_bool(gcc, kGConfTurboMode, NULL));
 	gtk_combo_box_set_active(framerate_combo,
@@ -312,7 +337,7 @@ static GtkWidget * load_plugin(void)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(accu_check),
 		gconf_client_get_bool(gcc, kGConfTransparency, NULL));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(display_fps_check),
-		gconf_client_get_int(gcc, kGConfDisplayFramerate, NULL));
+		gconf_client_get_bool(gcc, kGConfDisplayFramerate, NULL));
 	gtk_combo_box_set_active(speedhacks_combo,
 		gconf_client_get_int(gcc, kGConfSpeedhacks, NULL));
 #endif
@@ -341,22 +366,17 @@ static void write_config(void)
 {
 /* Write current settings to gconf */
 #if MAEMO_VERSION >= 5
-	gconf_client_set_bool(gcc, kGConfDisableAudio,
-		!hildon_check_button_get_active(audio_check), NULL);
+	gconf_client_set_bool(gcc, kGConfSound,
+		hildon_check_button_get_active(sound_check), NULL);
 	gconf_client_set_int(gcc, kGConfFrameskip,
 		hildon_picker_button_get_active(framerate_picker), NULL);
 	gconf_client_set_bool(gcc, kGConfDisplayFramerate,
 		hildon_check_button_get_active(display_fps_check), NULL);
 	gconf_client_set_bool(gcc, kGConfTurboMode,
 		hildon_check_button_get_active(turbo_check), NULL);
-
-	// For now, transparencies are always enabled in Fremantle
-	gconf_client_set_bool(gcc, kGConfTransparency, TRUE, NULL);
-	// Speedhacks always disabled
-	gconf_client_set_int(gcc, kGConfSpeedhacks,	FALSE, NULL);
 #else
-	gconf_client_set_bool(gcc, kGConfDisableAudio,
-		!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(audio_check)), NULL);
+	gconf_client_set_bool(gcc, kGConfSound,
+		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sound_check)), NULL);
 	gconf_client_set_bool(gcc, kGConfTurboMode,
 		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(turbo_check)), NULL);
 	gconf_client_set_int(gcc, kGConfFrameskip,
@@ -382,13 +402,15 @@ static GtkWidget **load_menu(guint *nitems)
 	const HildonSizeType button_size =
 		HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH;
 	menu_items[0] = hildon_gtk_button_new(button_size);
-	gtk_button_set_label(GTK_BUTTON(menu_items[0]), "Placeholder");
+	gtk_button_set_label(GTK_BUTTON(menu_items[0]), "Settings…");
 	menu_items[1] = hildon_gtk_button_new(button_size);
 	gtk_button_set_label(GTK_BUTTON(menu_items[1]), "Controls…");
 	menu_items[2] = hildon_gtk_button_new(button_size);
 	gtk_button_set_label(GTK_BUTTON(menu_items[2]), "About…");
 	*nitems = 3;
 
+	g_signal_connect(G_OBJECT(menu_items[0]), "clicked",
+					G_CALLBACK(advanced_item_callback), NULL);
 	g_signal_connect(G_OBJECT(menu_items[1]), "clicked",
 					G_CALLBACK(controls_item_callback), NULL);
 	g_signal_connect(G_OBJECT(menu_items[2]), "clicked",
@@ -399,15 +421,21 @@ static GtkWidget **load_menu(guint *nitems)
 	*nitems = 2;
 
 	GtkMenu* settings_menu = GTK_MENU(gtk_menu_new());
-	GtkMenuItem* controls_item =
-		GTK_MENU_ITEM(gtk_menu_item_new_with_label("Controls…"));
-	
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu_items[0]),
 		GTK_WIDGET(settings_menu));
+
+	GtkMenuItem* controls_item =
+		GTK_MENU_ITEM(gtk_menu_item_new_with_label("Controls…"));
 	gtk_menu_append(GTK_MENU(settings_menu), GTK_WIDGET(controls_item));
 
+	GtkMenuItem* advanced_item =
+		GTK_MENU_ITEM(gtk_menu_item_new_with_label("Advanced…"));
+	gtk_menu_append(GTK_MENU(settings_menu), GTK_WIDGET(advanced_item));
+
 	g_signal_connect(G_OBJECT(controls_item), "activate",
 					G_CALLBACK(controls_item_callback), NULL);
+	g_signal_connect(G_OBJECT(advanced_item), "activate",
+					G_CALLBACK(advanced_item_callback), NULL);
 	g_signal_connect(G_OBJECT(menu_items[1]), "activate",
 					G_CALLBACK(about_item_callback), NULL);
 #endif
@@ -420,19 +448,46 @@ static void update_menu(void)
 	// Nothing to update in the current menu
 }
 
+// From osso-games-startup
+#define MA_GAME_PLAY 1
+#define MA_GAME_RESTART 2
+#define MA_GAME_OPEN 3
+#define MA_GAME_SAVE 4
+#define MA_GAME_SAVE_AS 5
+#define MA_GAME_HELP 6
+#define MA_GAME_RECENT_1 7
+#define MA_GAME_RECENT_2 8
+#define MA_GAME_RECENT_3 9
+#define MA_GAME_RECENT_4 10
+#define MA_GAME_RECENT_5 11
+#define MA_GAME_RECENT_6 12
+#define MA_GAME_CLOSE 13
+#define MA_GAME_HIGH_SCORES 14
+#define MA_GAME_RESET 15
+#define MA_GAME_CHECKSTATE 16
+#define MA_GAME_SAVEMENU_REFERENCE 17
+#define ME_GAME_OPEN     20
+#define ME_GAME_SAVE     21
+#define ME_GAME_SAVE_AS  22
+#define MA_GAME_PLAYING_START 30
+#define MA_GAME_PLAYING 31
+
 static void plugin_callback(GtkWidget * menu_item, gpointer data)
 {
+#if MAEMO_VERSION >= 5
+	static int widgets_moved = 0;
+#endif
 	switch ((gint) data) {
-		case 20:	// ME_GAME_OPEN
+		case ME_GAME_OPEN:
 			save_load(get_parent_window());
 			break;
-		case 21:	// ME_GAME_SAVE
+		case ME_GAME_SAVE:
 			save_save(get_parent_window());
 			break;
-		case 22:	// ME_GAME_SAVE_AS
+		case ME_GAME_SAVE_AS:
 			save_save_as(get_parent_window());
 			break;
-		case 30:	// MA_GAME_PLAYING_START
+		case MA_GAME_PLAYING_START:
 			if (!menu_item) {
 				// Avoid duplicate message
 				break;
@@ -449,6 +504,56 @@ static void plugin_callback(GtkWidget * menu_item, gpointer data)
 				gtk_widget_destroy(note);
 			}
 			break;
+#if MAEMO_VERSION >= 5
+		// The above horrible hack continues here.
+		case MA_GAME_CHECKSTATE:
+			if (gs.ui->restart_button &&
+				gtk_widget_get_parent(gs.ui->restart_button)
+					 != GTK_WIDGET(buttons_hbox))
+			{
+				GtkWidget* old_parent = gtk_widget_get_parent(gs.ui->restart_button);
+				gtk_widget_reparent(gs.ui->restart_button,
+						GTK_WIDGET(buttons_hbox));
+				hildon_gtk_widget_set_theme_size(gs.ui->restart_button,
+					HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_THUMB_HEIGHT);
+				gtk_widget_set_size_request(gs.ui->restart_button, 200, -1);
+				gtk_box_set_child_packing(buttons_hbox, gs.ui->restart_button,
+						FALSE, FALSE, 0, GTK_PACK_END);
+
+				widgets_moved++;
+				if (widgets_moved == 1) {
+					gtk_widget_set_size_request(
+						gtk_widget_get_parent(GTK_WIDGET(buttons_hbox)),
+						-1, -1);
+				} else if (widgets_moved == 2) {
+					gtk_widget_destroy(old_parent);
+				}
+			}
+			break;
+		case MA_GAME_PLAYING:
+			if (gtk_widget_get_parent(gs.ui->play_button) != GTK_WIDGET(buttons_hbox))
+			{
+				GtkWidget* old_parent = gtk_widget_get_parent(gs.ui->play_button);
+				gtk_widget_reparent(gs.ui->play_button,
+						GTK_WIDGET(buttons_hbox));
+				hildon_gtk_widget_set_theme_size(gs.ui->play_button,
+					HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_THUMB_HEIGHT);
+				gtk_widget_set_size_request(gs.ui->play_button, 200, -1);
+				gtk_box_set_child_packing(buttons_hbox, gs.ui->play_button,
+						FALSE, FALSE, 0, GTK_PACK_START);
+
+				widgets_moved++;
+				if (widgets_moved == 1) {
+					gtk_widget_set_size_request(
+						gtk_widget_get_parent(GTK_WIDGET(buttons_hbox)),
+						-1, -1);
+				} else if (widgets_moved == 2) {
+					gtk_widget_destroy(old_parent);
+				}
+			}
+
+			break;
+#endif
 	}
 }
 
