@@ -65,9 +65,9 @@ void HgwConfig()
 		DIE("No Rom in Gconf!");
 	}
 
-	char no_audio = FALSE;
-	if (hgw_conf_request_bool(hgw, kGConfDisableAudio, &no_audio) == HGW_ERR_NONE) {
-		Config.enableAudio = no_audio ? false : true;
+	char sound = FALSE;
+	if (hgw_conf_request_bool(hgw, kGConfSound, &sound) == HGW_ERR_NONE) {
+		Config.enableAudio = sound ? true : false;
 	}
 
 	char turbo = FALSE;
@@ -85,11 +85,26 @@ void HgwConfig()
 		Settings.Transparency = transparency ? TRUE : FALSE;
 	}
 
+#if CONF_XSP
+	char xsp = TRUE;
+	if (hgw_conf_request_bool(hgw, kGConfXSP, &xsp) == HGW_ERR_NONE) {
+		if (!xsp) {
+			free(Config.scaler);
+			Config.scaler = strdup("2x");
+		}
+	}
+#endif
+
 	char displayFramerate = FALSE;
 	if (hgw_conf_request_bool(hgw, kGConfDisplayFramerate, &displayFramerate) == HGW_ERR_NONE) {
 		Settings.DisplayFrameRate = displayFramerate ? TRUE : FALSE;
 	}
 
+	char displayControls = FALSE;
+	if (hgw_conf_request_bool(hgw, kGConfDisplayControls, &displayControls) == HGW_ERR_NONE) {
+		Config.touchscreenShow = displayControls ? true : false;
+	}
+
 	int speedhacks = 0;
 	if (hgw_conf_request_int(hgw, kGConfSpeedhacks, &speedhacks) == HGW_ERR_NONE) {
 		if (speedhacks <= 0) {
