@@ -14,14 +14,16 @@ extern struct config {
 	bool snapshotSave;
 	/** Create fullscreen surface */
 	bool fullscreen;
-	/** Using xsp (thus take care of doubling coordinates where appropiate) */
-	bool xsp;
+	/** Name of the scaler to use or NULL for default */
+	char * scaler;
 	/** Audio output enabled */
 	bool enableAudio;
 	/** Speedhacks file to use */
 	char * hacksFile;
 	/** Enable touchscreen controls */
 	bool touchscreenInput;
+	/** Display touchscreen controls grid */
+	bool touchscreenShow;
 	/** Current scancode->joypad mapping */
 	unsigned short joypad1Mapping[256];
 	unsigned char action[256];
@@ -33,8 +35,10 @@ extern struct config {
 extern struct gui {
 	/** Size of the GUI Window */
 	unsigned short Width, Height;
-	/** Size of the rendering area, relative to window. 2x if Xsp on. */
+	/** Size of the (scaled) rendering area, relative to window. */
 	unsigned short RenderX, RenderY, RenderW, RenderH;
+	/** Scaling ratio */
+	unsigned short Scale;
 } GUI;
 void S9xVideoToggleFullscreen();
 void S9xVideoOutputFocus(bool hasFocus);
@@ -48,6 +52,7 @@ void S9xAudioOutputEnable(bool enable);
 EXTERN_C void S9xInitInputDevices();
 void S9xDeinitInputDevices();
 void S9xInputScreenChanged();
+void S9xInputScreenDraw(int pixelSize, void * buffer, int pitch);
 
 // Input actions
 #define kActionNone						0
